Elementary
==========

This module implements elementary functions such as trigonometric, hyperbolic
as well as functions like ``Abs``, ``Max``, ``sqrt`` etc.


diofant.functions.elementary.complexes
======================================

re
--

.. autoclass:: diofant.functions.elementary.complexes.re
   :members:

im
--

.. autoclass:: diofant.functions.elementary.complexes.im
   :members:

sign
----

.. autoclass:: diofant.functions.elementary.complexes.sign
   :members:

Abs
---

.. autoclass:: diofant.functions.elementary.complexes.Abs
   :members:

adjoint
-------

.. autoclass:: diofant.functions.elementary.complexes.adjoint
   :members:

arg
---

.. autoclass:: diofant.functions.elementary.complexes.arg
   :members:

conjugate
---------

.. autoclass:: diofant.functions.elementary.complexes.conjugate
   :members:

polar_lift
----------

.. autoclass:: diofant.functions.elementary.complexes.polar_lift
   :members:

periodic_argument
-----------------

.. autoclass:: diofant.functions.elementary.complexes.periodic_argument
   :members:

principal_branch
----------------

.. autoclass:: diofant.functions.elementary.complexes.principal_branch
   :members:

transpose
---------

.. autoclass:: diofant.functions.elementary.complexes.transpose
   :members:


diofant.functions.elementary.trigonometric
==========================================

Trigonometric Functions
=======================

sin
---

.. autoclass:: diofant.functions.elementary.trigonometric.sin
   :members:

cos
---

.. autoclass:: diofant.functions.elementary.trigonometric.cos
   :members:

tan
---

.. autoclass:: diofant.functions.elementary.trigonometric.tan
   :members:

cot
---

.. autoclass:: diofant.functions.elementary.trigonometric.cot
   :members:

sec
---

.. autoclass:: diofant.functions.elementary.trigonometric.sec
   :members:

csc
---

.. autoclass:: diofant.functions.elementary.trigonometric.csc
   :members:


Trigonometric Inverses
======================

asin
----

.. autoclass:: diofant.functions.elementary.trigonometric.asin
   :members:

acos
----

.. autoclass:: diofant.functions.elementary.trigonometric.acos
   :members:

asec
----

.. autoclass:: diofant.functions.elementary.trigonometric.asec
   :members:

atan
----

.. autoclass:: diofant.functions.elementary.trigonometric.atan
   :members:

acot
----

.. autoclass:: diofant.functions.elementary.trigonometric.acot
   :members:

acsc
----

.. autoclass:: diofant.functions.elementary.trigonometric.acsc
   :members:

atan2
-----

.. autoclass:: diofant.functions.elementary.trigonometric.atan2
   :members:


diofant.functions.elementary.hyperbolic
=======================================

Hyperbolic Functions
====================


HyperbolicFunction
------------------

.. autoclass:: diofant.functions.elementary.hyperbolic.HyperbolicFunction
   :members:

sinh
----

.. autoclass:: diofant.functions.elementary.hyperbolic.sinh
   :members:

cosh
----

.. autoclass:: diofant.functions.elementary.hyperbolic.cosh
   :members:

tanh
----

.. autoclass:: diofant.functions.elementary.hyperbolic.tanh
   :members:

coth
----

.. autoclass:: diofant.functions.elementary.hyperbolic.coth
   :members:

sech
----

.. autoclass:: diofant.functions.elementary.hyperbolic.sech
   :members:

csch
----

.. autoclass:: diofant.functions.elementary.hyperbolic.csch
   :members:


Hyperbolic Inverses
===================

asinh
-----

.. autoclass:: diofant.functions.elementary.hyperbolic.asinh
   :members:

acosh
-----

.. autoclass:: diofant.functions.elementary.hyperbolic.acosh
   :members:

atanh
-----

.. autoclass:: diofant.functions.elementary.hyperbolic.atanh
   :members:

acoth
-----

.. autoclass:: diofant.functions.elementary.hyperbolic.acoth
   :members:


diofant.functions.elementary.integers
=====================================

ceiling
-------

.. autoclass:: diofant.functions.elementary.integers.ceiling
   :members:


floor
-----

.. autoclass:: diofant.functions.elementary.integers.floor
   :members:


RoundFunction
-------------

.. autoclass:: diofant.functions.elementary.integers.RoundFunction


diofant.functions.elementary.exponential
========================================

exp
---

.. autofunction:: diofant.functions.elementary.exponential.exp

exp_polar
---------

.. autoclass:: diofant.functions.elementary.exponential.exp_polar
   :members:

LambertW
--------

.. autoclass:: diofant.functions.elementary.exponential.LambertW
   :members:

log
---

.. autoclass:: diofant.functions.elementary.exponential.log
   :members:


diofant.functions.elementary.piecewise
======================================

ExprCondPair
------------

.. autoclass:: diofant.functions.elementary.piecewise.ExprCondPair
   :members:


Piecewise
---------

.. autoclass:: diofant.functions.elementary.piecewise.Piecewise
   :members:

.. autofunction:: diofant.functions.elementary.piecewise.piecewise_fold


diofant.functions.elementary.miscellaneous
==========================================

IdentityFunction
----------------

.. autoclass:: diofant.functions.elementary.miscellaneous.IdentityFunction
   :members:

Min
---

.. autoclass:: diofant.functions.elementary.miscellaneous.Min
   :members:


Max
---

.. autoclass:: diofant.functions.elementary.miscellaneous.Max
   :members:

root
----

.. autofunction:: diofant.functions.elementary.miscellaneous.root

real_root
---------

.. autofunction:: diofant.functions.elementary.miscellaneous.real_root

sqrt
----

.. autofunction:: diofant.functions.elementary.miscellaneous.sqrt
